# T3CO Output Parameters Descriptions

| **T3CO Output Parameter**                     | **Description**                                                                                                                                                                                                                                                         | **Data type(s)**       |
| --------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | --------------- |
| selection                                     | Selection number of vehicle/scenario                                                                                                                                                                                                                                | int             |
| scenario_name                                 | Name of the selected scenario/vehicle                                                                                                                                                                                                                               | string          |
| veh_year                                      | Current year                                                                                                                                                                                                                                                        | int             |
| veh_pt_type                                   | Vehicle powertrain type                                                                                                                                                                                                                                             | string          |
| pareto_front_number                           | Optimization solution number from pareto front                                                                                                                                                                                                                      | int             |
| run_time_[s]                                  | T3CO run time for selected vehicle/scenario                                                                                                                                                                                                                         | float           |
| algorithm                                     | Algorithm for pymoo optimization. From  ["NSGA2", "PatternSearch"]                                                                                                                                                                                                  | string          |
| n_gen                                         | Number of generations of genetic algorithm optimization                                                                                                                                                                                                             | int             |
| fvals_over_gens                               | Optimization objective space values across generations                                                                                                                                                                                                              | float           |
| design_cyc_trace_miss_dist_frac               | Fractional difference between achieved cumulative distance and prescribed cumulative distance. If composite drivecycle is input, the distance trace miss is output as a list                                                                                        | dict/list[dict] |
| design_cyc_trace_miss_time_frac               | Fractional difference between achieved time when trace miss is and prescribed cumulative distance. If composite drivecycle is input, the time trace miss is output as a list                                                                                        | dict/list[dict] |
| design_cyc_trace_miss_speed_mps               | Maximum speed (mps) by which vehicle’s speed falls behind prescribed speed trace. If composite drivecycle is input, the time trace miss is output as a list                                                                                                         | dict/list[dict] |
| design_cycle_EA_err                           | Fractional difference between achieved energy consumption vs consumption estimated based on the input drivecycle. Checks for conservation of energy in the simulated results.                                                                                       | dict/list[dict] |
| accel_EA_err                                  | Fractional difference between achieved energy consumption vs consumption estimated based on the acceleration test drivecycle with current vehicle mass.  Checks for conservation of energy in the simulated results                                                 | dict/list[dict] |
| accel_loaded_EA_err                           | Fractional difference between achieved energy consumption vs consumption estimated based on the acceleration test drivecycle with fully laden vehicle. Checks for conservation of energy in the simulated results                                                   | dict/list[dict] |
| grade_6_EA_err                                | Fractional difference between achieved energy consumption vs consumption estimated based on the 6 % gradeability test drivecycle with fully laden vehicle.  Checks for conservation of energy in the simulated results                                              | dict/list[dict] |
| grade_1p25_EA_err                             | Fractional difference between achieved energy consumption vs consumption estimated based on the 1.25 % gradeability test drivecycle with fully laden vehicle.  Checks for conservation of energy in the simulated results                                           | dict/list[dict] |
| final_cda_pct                                 | Optimization result for percent improvement in Cd\*A (drag coefficient times frontal area) - based on aero drag improvement curve                                                                                                                                   | float           |
| final_eng_eff_pct                             | Optimization result for percent improvement in engine efficiency - based on engine efficiency improvement curve                                                                                                                                                     | float           |
| final_ltwt_pct                                | Optimization result for percent improvement in vehicle mass - based on lightweighting improvement curve                                                                                                                                                             | float           |
| final_max_motor_kw                            | Optimization result for motor power in kW - bound between scenario.knob_min_motor_kw and scenario.knob_max_motor_kw                                                                                                                                                 | float           |
| final_battery_kwh                             | Optimization result for ESS max capacity in kWh - bound between scenario.knob_min_ess_kwh and scenario.knob_max_ess_kwh                                                                                                                                             | float           |
| final_max_fc_kw                               | Optimization result for fuel converter max power in kW - bound between scenario.knob_min_fc_kw and scenario.knob_max_fc_kw                                                                                                                                          | float           |
| final_fs_kwh                                  | Optimization result for fuel storage max capacity in kWh - bound between scenario.knob_min_fs_kwh and scenario.knob_max_fs_kwh                                                                                                                                      | float           |
| range_ach_mi                                  | Range achieved by vehicle based on drivecycle simulation                                                                                                                                                                                                            | float           |
| target_range_mi                               | Target range constraint for design vehicle during optimization                                                                                                                                                                                                      | float           |
| delta_range_mi                                | Difference between range achieved from simulation and target range of the design vehicle                                                                                                                                                                            | float           |
| min_speed_at_6pct_grade_in_5min_ach_mph       | Final speed achieved by design vehicle during 6 % gradeability test run for 5 mins                                                                                                                                                                                  | float           |
| target_min_speed_at_6pct_grade_in_5min_mph    | Target speed for design vehicle during 6 % gradeability test run for 5 mins                                                                                                                                                                                         | float           |
| delta_min_speed_at_6pct_grade_in_5min_mph     | Difference between final speed achieved and target speed during 6% gradeability test                                                                                                                                                                                | float           |
| min_speed_at_1p25pct_grade_in_5min_ach_mph    | Final speed achieved by design vehicle during 1.25 % gradeability test run for 5 mins                                                                                                                                                                               | float           |
| target_min_speed_at_1p25pct_grade_in_5min_mph | Target speed for design vehicle during 1.25 % gradeability test run for 5 mins                                                                                                                                                                                      | float           |
| delta_min_speed_at_1p25pct_grade_in_5min_mph  | Difference between final speed achieved and target speed during 1.25% gradeability test                                                                                                                                                                             | float           |
| max_time_0_to_60mph_at_gvwr_ach_s             | Time taken achieved by fully laden design vehicle during acceleration for 0 to 60mph                                                                                                                                                                                | float           |
| target_max_time_0_to_60mph_at_gvwr_s          | Target time taken for fully laden design vehicle during acceleration for 0 to 60mph                                                                                                                                                                                 | float           |
| delta_max_time_0_to_60mph_at_gvwr_s           | Difference between time taken by simulated vehicle and target time for fully laden acceleration test from 0 to 60mph                                                                                                                                                | float           |
| max_time_0_to_30mph_at_gvwr_ach_s             | Time taken achieved by fully laden design vehicle during acceleration for 0 to 30mph                                                                                                                                                                                | float           |
| target_max_time_0_to_30mph_at_gvwr_s          | Target time taken for fully laden design vehicle during acceleration for 0 to 30mph                                                                                                                                                                                 | float           |
| delta_max_time_0_to_30mph_at_gvwr_s           | Difference between time taken by simulated vehicle and target time for fully laden acceleration test from 0 to 30mph                                                                                                                                                | float           |
| glider_cost_dol                               | Estimated glider component cost in dollars - contributes to MSRP                                                                                                                                                                                                    | float           |
| fuel_converter_cost_dol                       | Estimated fuel converter component cost in dollars - contributes to MSRP                                                                                                                                                                                            | float           |
| fuel_storage_cost_dol                         | Estimated fuel storage component cost in dollars - contributes to MSRP                                                                                                                                                                                              | float           |
| motor_control_power_elecs_cost_dol            | Estimated motor and power electronics component cost in dollars - contributes to MSRP                                                                                                                                                                               | float           |
| plug_cost_dol                                 | Estimated plugin charger component cost in dollars - contributes to MSRP                                                                                                                                                                                            | float           |
| battery_cost_dol                              | Estimated battery/ESS component cost in dollars - contributes to MSRP                                                                                                                                                                                               | float           |
| purchase_tax_dol                              | Estimated purchased/excise tax  in dollars - calculated from MSRP                                                                                                                                                                                                   | float           |
| msrp_total_dol                                | Estimated manufacturer's suggested retail price in dollars - calculated from vehicle component costs                                                                                                                                                                | float           |
| total_fuel_cost_dol                           | Estimated fuel operating cost in dollars - calculated from energy consumption and fuel prices                                                                                                                                                                       | float           |
| total_maintenance_cost_dol                    | Estimated maintenance operating cost in dollars - calculated from VMT and scenario.maint_oper_cost_dol_per_mi                                                                                                                                                       | float           |
| mpgge                                         | Miles per Gallon of Gasoline Equivalent - from drivecycle simulation                                                                                                                                                                                                | float           |
| grid_mpgge                                    | Miles per Gallon of Gasoline Equivalent effect to grid - mpgge times charger efficiency                                                                                                                                                                             | float           |
| mpgde                                         | Miles per Gallon of Diesel Equivalent - from drivecycle simulation                                                                                                                                                                                                  | float           |
| kwh_per_mi                                    | Energy spent per mile of operation - estimated from drivecycle simulation                                                                                                                                                                                           | float           |
| payload_cap_cost_multiplier                   | Lost payload capacity opportunity cost factor - represents the fractionally extra vehicle required to compensate for reduced payload capacity compared to conventional vehicle - Currently only for Class 8 vehicles                                                | float           |
| total_fueling_dwell_time_hr                   | Total dwell time of vehicle due to fueling/charging - used to estimate downtime opportunity cost                                                                                                                                                                    | float           |
| total_mr_downtime_hr                          | Total dwell time of vehicle due to maintenance & repair (planned, unplanned, and tire replacement) - used to estimate downtime opportunity cost                                                                                                                     | float           |
| total_downtime_hr                             | Total downtime due to fueling/charging and maintenance events                                                                                                                                                                                                       | float           |
| fueling_dwell_labor_cost_dol                  | Estimated labor cost incurred during fueling/charging dwell time                                                                                                                                                                                                    | float           |
| fueling_downtime_oppy_cost_dol                | Estimated opportunity cost associated with fueling/charging dwell time                                                                                                                                                                                              | float           |
| mr_downtime_oppy_cost_dol                     | Estimated labor cost incurred during maintenance & repair downtime                                                                                                                                                                                                  | float           |
| discounted_downtime_oppy_cost_dol             | Estimated discounted opportunity cost for both fueling dwell time and M&R downtime in dollars - estimation is based on config.TCO_method                                                                                                                            | float           |
| payload_capacity_cost_dol                     | Lost payload capacity opportunity cost in dollars - estimated from payload_cap_cost_multiplier and estimated tco                                                                                                                                                    | float           |
| insurance_cost_dol                            | Estimated insurance cost of vehicle in dollars - estimated from MSRP and scenario.insurance_rates_pct_per_yr                                                                                                                                                        | float           |
| residual_cost_dol                             | Estimated residual cost of vehicle in dollars (residual value is the negative of residual cost)                                                                                                                                                                     | float           |
| discounted_tco_dol                            | Estimated discounted Total Cost of Ownership in dollars - Calculated using one of DIRECT or EFFICIENCY method from different cost components, discounted year over year at a rate of scenario.discount_rate_pct_per_yr, and calculated for scenario.vehicle_life_yr | float           |